PipPosition class

Represents the position of the PiP player on the screen

Constructors

PipPosition({required Offset offset, PipAnchor anchor = PipAnchor.bottomRight})
Creates a new PipPosition
const

Properties

anchor → PipAnchor
The anchor position (corner) of the PiP player
final
hashCode → int
The hash code for this object.
no setterinherited
offset → Offset
The current position of the PiP player
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Offset? offset, PipAnchor? anchor}) → PipPosition
Creates a copy of this position with the given fields replaced
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited