PipSettings class

Settings for the PiP player

Constructors

PipSettings({double collapsedWidth = 160.0, double collapsedHeight = 90.0, double expandedWidth = 320.0, double expandedHeight = 240.0, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(12.0)), EdgeInsets screenPadding = const EdgeInsets.all(16.0), Duration animationDuration = const Duration(milliseconds: 250), Curve animationCurve = Curves.easeOutCubic, Color backgroundColor = Colors.black, Color shadowColor = const Color.fromARGB(255, 196, 196, 196), double elevation = 8.0, Offset offset = const Offset(0, 0), bool showDragHandle = true, Color dragHandleColor = Colors.white60, bool showCloseButton = true, Color closeButtonColor = Colors.white, bool showExpandButton = true, Color expandButtonColor = Colors.white, bool showProgressBar = true, Color progressBarColor = Colors.red, Color progressBarBackgroundColor = Colors.grey, double progressBarHeight = 3.0, bool snapToEdges = true, double snapThreshold = 64.0, bool allowDrag = true, bool allowExpand = true, bool showBackdropWhenExpanded = false, Color backdropColor = Colors.black54, bool showTitle = true, bool isReelsMode = false, TextStyle titleStyle = const TextStyle(color: Colors.white, fontSize: 14.0, fontWeight: FontWeight.w500), bool showControls = true, double controlsHeight = 48.0, Color controlsBackgroundColor = Colors.black87, double reelsWidth = 30, double reelsHeight = 100, double reelsSliderSize = 25, Color reelsBackgroundColor = Colors.black45, Color reelsSliderColor = Colors.white, IconData reelsSliderIcon = Icons.drag_handle, Color reelsSliderIconColor = Colors.black, double reelsDragSensitivity = 50.0})
Creates a new PipSettings
const

Properties

allowDrag → bool
Whether to allow dragging the PiP player
final
allowExpand → bool
Whether to allow expanding the PiP player
final
animationCurve → Curve
The curve of the animations
final
animationDuration → Duration
The duration of the animations
final
backdropColor → Color
The color of the backdrop when expanded
final
backgroundColor → Color
The background color of the PiP player
final
borderRadius → BorderRadius
The border radius of the PiP player
final
closeButtonColor → Color
The color of the close button
final
collapsedHeight → double
The height of the PiP player when collapsed
final
collapsedWidth → double
The width of the PiP player when collapsed
final
controlsBackgroundColor → Color
The background color of the controls section
final
controlsHeight → double
The height of the controls section
final
dragHandleColor → Color
The color of the drag handle
final
elevation → double
The elevation of the PiP player
final
expandButtonColor → Color
The color of the expand button
final
expandedHeight → double
The height of the PiP player when expanded
final
expandedWidth → double
The width of the PiP player when expanded
final
hashCode → int
The hash code for this object.
no setterinherited
isReelsMode → bool
Show reels slide up/doun button
final
offset → Offset
The offset of the PiP player
final
progressBarBackgroundColor → Color
The background color of the progress bar
final
progressBarColor → Color
The color of the progress bar
final
progressBarHeight → double
The height of the progress bar
final
reelsBackgroundColor → Color
final
reelsDragSensitivity → double
final
reelsHeight → double
final
reelsSliderColor → Color
final
reelsSliderIcon → IconData
final
reelsSliderIconColor → Color
final
reelsSliderSize → double
final
reelsWidth → double
Reels widget meta data
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenPadding → EdgeInsets
The padding from the edge of the screen
final
shadowColor → Color
The shadow color of the PiP player
final
showBackdropWhenExpanded → bool
Whether to show a backdrop when expanded
final
showCloseButton → bool
Whether to show the close button
final
showControls → bool
Whether to show controls when expanded
final
showDragHandle → bool
Whether to show the drag handle
final
showExpandButton → bool
Whether to show the expand button
final
showProgressBar → bool
Whether to show the progress bar
final
showTitle → bool
Whether to show a title when expanded
final
snapThreshold → double
The threshold for snapping to the edges
final
snapToEdges → bool
Whether to snap to the edges of the screen
final
titleStyle → TextStyle
The style of the title
final

Methods

copyWith({double? collapsedWidth, double? collapsedHeight, double? expandedWidth, double? expandedHeight, BorderRadius? borderRadius, EdgeInsets? screenPadding, Duration? animationDuration, Curve? animationCurve, Color? backgroundColor, Color? shadowColor, double? elevation, bool? showDragHandle, Color? dragHandleColor, bool? showCloseButton, Color? closeButtonColor, bool? showExpandButton, Color? expandButtonColor, bool? showProgressBar, Color? progressBarColor, Color? progressBarBackgroundColor, double? progressBarHeight, bool? snapToEdges, double? snapThreshold, bool? allowDrag, bool? allowExpand, bool? showBackdropWhenExpanded, Color? backdropColor, bool? showTitle, TextStyle? titleStyle, bool? showControls, double? controlsHeight, Color? controlsBackgroundColor, Color? reelsBtnColor, bool? isReelsMode, double? reelsWidth, double? reelsHeight, double? reelsSliderSize, Color? reelsBackgroundColor, Color? reelsSliderColor, IconData? reelsSliderIcon, Color? reelsSliderIconColor, double? reelsDragSensitivity, Offset? offset}) → PipSettings
Creates a copy of this settings with the given fields replaced
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

chat → PipSettings
Settings for a chat bubble
no setter
map → PipSettings
Settings for a mini map
no setter
video → PipSettings
Default settings for a video player
no setter