PipController class

Controller for the PiP player

Inheritance

Constructors

PipController({PipSettings settings = const PipSettings(), String title = '', PipPosition? initialPosition, double bottomSafePadding = 80.0, bool isSnaping = true, double margin = 10.0})

Properties

bottomSafePadding ↔ double
Ensuring visibility at the bottom
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
height → double
no setter
isDragging → bool
no setter
isExpanded → bool
no setter
isSnaping ↔ bool
Enable Snaps the PiP player to the nearest edge
getter/setter pair
isVisible → bool
no setter
margin ↔ double
Minimum margin to ensure safe area
getter/setter pair
position → PipPosition
no setter
progress → double
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenSize → Size
no setter
settings → PipSettings
no setter
title → String
no setter
width → double
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
collapse() → void
dispose() → void
Discards any resources used by the object.
inherited
expand() → void
hide() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setDragging(bool dragging) → void
setScreenSize(Size size) → void
setTitle(String title) → void
show() → void
snapToEdge() → void
toggleExpanded() → void
toggleVisibility() → void
toString() → String
A string representation of this object.
inherited
updatePosition(Offset offset) → void
updateProgress(double value) → void
updateSettings(PipSettings settings) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited