PipControls class

Default controls for the PiP player

Inheritance

Constructors

PipControls({Key? key, bool isPlaying = false, VoidCallback? onPlayPause, VoidCallback? onRewind, VoidCallback? onForward, VoidCallback? onFullscreen, Color iconColor = Colors.white, double iconSize = 24.0, Color backgroundColor = Colors.black87, double height = 48.0})
Creates new PipControls
const

Properties

backgroundColor → Color
The background color of the controls
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
The height of the controls
final
iconColor → Color
The color of the icons
final
iconSize → double
The size of the icons
final
isPlaying → bool
Whether the content is playing
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onForward → VoidCallback?
Callback when the forward button is pressed
final
onFullscreen → VoidCallback?
Callback when the fullscreen button is pressed
final
onPlayPause → VoidCallback?
Callback when the play/pause button is pressed
final
onRewind → VoidCallback?
Callback when the rewind button is pressed
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited